@@ -581,5 +581,11 @@ $(document).ready(function() {
 									$(this).attr('value', $(this).attr('value') + " \u2192");
 								}
 							});
+	
+	//iPad Viewport
+	if( navigator.userAgent.match(/iPad/i) != null ){  
+		viewport = document.querySelector("meta[name=viewport]");  
+		viewport.setAttribute('content', "width=device-width, maximum-scale=0.9, user-scalable=no");  
+	}
 });
 
