@@ -297,8 +297,8 @@ class CommonBrowserView(BrowserView):
         
         dates = "%s"%(samedate and (event.start() is not None and event.start().strftime('%A %d %B %Y') or event.end().strftime('%A %d %B %Y')) or "%s to %s"%(event.start().strftime('%A %d %B %Y'), event.end().strftime('%A %d %B %Y')))
         
-        openingHour = event.start() is not None and event.start().strftime('%I:%M%p') or ""
-        closingHour = event.end() is not None and event.end().strftime('to %I:%M%p') or ""
+        openingHour = event.start() is not None and event.start().strftime('%H:%M') or ""
+        closingHour = event.end() is not None and event.end().strftime('to %H:%M') or ""
         hoursExist = 'to %s'%openingHour != closingHour
         
         hours = hoursExist and '<span class="hours">, %s %s</span>'%(openingHour, closingHour) or '<span class="hours">, %s</span>'%openingHour
